summaryrefslogtreecommitdiffstats
path: root/src/kchmmainwindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kchmmainwindow.cpp')
-rw-r--r--src/kchmmainwindow.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/src/kchmmainwindow.cpp b/src/kchmmainwindow.cpp
index 31130dd..04530a9 100644
--- a/src/kchmmainwindow.cpp
+++ b/src/kchmmainwindow.cpp
@@ -82,7 +82,7 @@ KCHMMainWindow::KCHMMainWindow()
m_currentSettings = new KCHMSettings;
- // Create the initial layout - a splitter with tab window in left, and text browser in right
+ // Create the initial tqlayout - a splitter with tab window in left, and text browser in right
m_windowSplitter = new TQSplitter(this);
m_tabWidget = new KTQTabWidget( m_windowSplitter );
m_viewWindowMgr = new KCHMViewWindowMgr( m_windowSplitter );
@@ -202,9 +202,9 @@ bool KCHMMainWindow::loadChmFile ( const TQString &fileName, bool call_open_page
showOrHideIndexWindow( m_tabIndexPage );
showOrHideSearchWindow( m_tabSearchPage );
- m_bookmarkWindow->invalidate();
- m_navToolbar->updateIconStatus( false, false );
- m_viewWindowMgr->invalidate();
+ m_bookmarkWindow->tqinvalidate();
+ m_navToolbar->updateIcontqStatus( false, false );
+ m_viewWindowMgr->tqinvalidate();
refreshCurrentBrowser();
if ( m_currentSettings->loadSettings (fileName) )
@@ -265,7 +265,7 @@ bool KCHMMainWindow::loadChmFile ( const TQString &fileName, bool call_open_page
mbox.exec();
statusBar()->message(
- i18n("Could not load file %1").arg(fileName),
+ i18n("Could not load file %1").tqarg(fileName),
2000 );
delete new_chmfile;
return false;
@@ -312,7 +312,7 @@ void KCHMMainWindow::refreshCurrentBrowser( )
setCaption ( title );
- currentBrowser()->invalidate();
+ currentBrowser()->tqinvalidate();
if ( m_contentsWindow )
m_contentsWindow->refillTableOfContents();
@@ -368,7 +368,7 @@ bool KCHMMainWindow::openPage( const TQString & srcurl, unsigned int flags )
case KCHMConfig::ACTION_ASK_USER:
if ( TQMessageBox::question(this,
i18n("%1 - remote link clicked - %2") . arg(APP_NAME) . arg(p1),
- i18n("A remote link %1 will start the external program to open it.\n\nDo you want to continue?").arg( url ),
+ i18n("A remote link %1 will start the external program to open it.\n\nDo you want to continue?").tqarg( url ),
i18n("&Yes"), i18n("&No"),
TQString(), 0, 1 ) )
return false;
@@ -403,7 +403,7 @@ bool KCHMMainWindow::openPage( const TQString & srcurl, unsigned int flags )
{
if ( TQMessageBox::question( this,
i18n( "%1 - link to a new CHM file clicked"). arg(APP_NAME),
- i18n( "You have clicked a link, which leads to a new CHM file %1.\nThe current file will be closed.\n\nDo you want to continue?").arg( p1 ),
+ i18n( "You have clicked a link, which leads to a new CHM file %1.\nThe current file will be closed.\n\nDo you want to continue?").tqarg( p1 ),
i18n( "&Yes" ), i18n( "&No" ),
TQString(), 0, 1 ) )
return false;
@@ -563,7 +563,7 @@ void KCHMMainWindow::setTextEncoding( const LCHMTextEncoding * encoding )
m_chmFile->setCurrentEncoding( encoding );
m_searchToolbar->setChosenEncodingInMenu( encoding );
// Because updateView() will call view->invalidate(), which clears the view->getOpenedPage(),
// we have to make a copy of it.
TQString url = currentBrowser()->getOpenedPage();
@@ -809,14 +809,14 @@ void KCHMMainWindow::slotChangeSettingsMenuItemActivated()
&& appConfig.m_useSearchEngine == KCHMConfig::SEARCH_USE_CHM )
{
appConfig.m_useSearchEngine = KCHMConfig::SEARCH_USE_MINE;
- m_searchWindow->invalidate();
+ m_searchWindow->tqinvalidate();
}
if ( dlg.m_useSearchEngineInternal->isChecked()
&& appConfig.m_useSearchEngine == KCHMConfig::SEARCH_USE_MINE )
{
appConfig.m_useSearchEngine = KCHMConfig::SEARCH_USE_CHM;
- m_searchWindow->invalidate();
+ m_searchWindow->tqinvalidate();
}
appConfig.m_advExternalEditorPath = dlg.m_advExternalProgramName->text();
@@ -932,7 +932,7 @@ void KCHMMainWindow::showOrHideContextWindow( int tabindex )
void KCHMMainWindow::showOrHideIndexWindow( int tabindex )
{
// Test whether to show/invalidate the index window
if ( tabindex == -1 )
{
if ( m_indexWindow )
@@ -950,7 +950,7 @@ void KCHMMainWindow::showOrHideIndexWindow( int tabindex )
m_tabWidget->insertTab (m_indexWindow, i18n( "Index" ), tabindex);
}
else
- m_indexWindow->invalidate();
+ m_indexWindow->tqinvalidate();
}
}
@@ -973,7 +973,7 @@ void KCHMMainWindow::showOrHideSearchWindow( int tabindex )
m_tabWidget->insertTab (m_searchWindow, i18n( "Search" ), tabindex);
}
else
- m_searchWindow->invalidate();
+ m_searchWindow->tqinvalidate();
}
}
@@ -1178,12 +1178,12 @@ void KCHMMainWindow::locateInContentTree( const TQString & url )
void KCHMMainWindow::slotOnTreeDoubleClicked( TQListViewItem * item, const TQPoint &, int )
{
- // Open/close only existing item which have children
+ // Open/close only existing item which have tqchildren
if ( !item || item->childCount() == 0 )
return;
item->setOpen( !item->isOpen() );
- item->repaint();
+ item->tqrepaint();
}
bool KCHMMainWindow::event( TQEvent * e )
@@ -563,7 +563,7 @@ void KCHMMainWindow::setTextEncoding( const LCHMTextEncoding * encoding )
m_chmFile->setCurrentEncoding( encoding );
m_searchToolbar->setChosenEncodingInMenu( encoding );
- // Because updateView() will call view->invalidate(), which clears the view->getOpenedPage(),
+ // Because updateView() will call view->tqinvalidate(), which clears the view->getOpenedPage(),
// we have to make a copy of it.
TQString url = currentBrowser()->getOpenedPage();
@@ -932,7 +932,7 @@ void KCHMMainWindow::showOrHideContextWindow( int tabindex )
void KCHMMainWindow::showOrHideIndexWindow( int tabindex )
{
- // Test whether to show/invalidate the index window
+ // Test whether to show/tqinvalidate the index window
if ( tabindex == -1 )
{